@@ -12,4 +12,4 @@ from donb_tools.functions import get_package_folder
 # pylint: disable=missing-function-docstring
 def get_hook_dirs() -> List[str]:
     package_folder = get_package_folder()
-    return [str(package_folder.parent.absolute())]
+    return [str(package_folder.absolute())]
